pub struct HomModule<M: Module> {
algebra: Arc<Field>,
source: Arc<FreeModule<M::Algebra>>,
target: Arc<M>,
pub block_structures: OnceBiVec<BlockStructure>,
}Expand description
Given a module N and a free module M, this is the module Hom(M, N) as a module over the ground field.
This requires N to be bounded, and is graded opposite to the usual grading so that Hom(M, N) is bounded below.
Fields
algebra: Arc<Field>source: Arc<FreeModule<M::Algebra>>target: Arc<M>block_structures: OnceBiVec<BlockStructure>Implementations