pub struct PPartAllocation {
m: Matrix2D,
diagonal: PPart,
p_part: PPart,
}Expand description
The parts of a PPartMultiplier that involve heap allocation.
This lets us reuse the allocation across multiple different multipliers. Reusing the whole PPartMultiplier is finicky but doable due to lifetime issues. However, it appears to be less performant.
Fields
m: Matrix2Ddiagonal: PPartp_part: PPartImplementations
Sourceimpl PPartAllocation
impl PPartAllocation
Sourcepub fn with_capacity(n: usize) -> Self
pub fn with_capacity(n: usize) -> Self
This creates a PPartAllocation with enough capacity to handle mulitiply elements with of total degree < 2^n - ε at p = 2.
pub fn with_local(f: impl FnOnce(Self) -> Self)